@@ -7,7 +7,7 @@ import packaging.version
 from core_changelog_md.common.enums import ChangeTypes
 from core_changelog_md.common.exceptions import UnCorrectTitleException, \
     MissedVersionsSymbolException, VersionOverTextException, NotDetectVersionException, VersionDateConvertException, \
-    UnDetectLine
+    UnDetectLine, MissChangeBlock
 from core_changelog_md.exceptions import VersionNotFoundException
 from core_changelog_md.objects.changes import ChangeCollection, ChangeBlock
 from core_changelog_md.objects.version import VersionCollection, VersionBlock
@@ -120,15 +120,17 @@ class Changelog(object):
                     date=Changelog.check_version_date(version_name=item),
                     change_collection=ChangeCollection()
                 ))
-                change_block = None
+                change_tag = None
                 continue
-            # Старт обработки нового change-block
+            # Старт обработки нового change-tag
             elif item.strip().startswith("###"):
                 change_tag = ChangeTypes.get_by_tag(tag=item.replace("#", '').strip())
                 obj.versions.get_by_name(version_name=version_name) \
                     .change_blocks[change_tag] = ChangeBlock(change_type=change_tag)
                 continue
             elif item.strip().startswith("-"):
+                if change_tag is None:
+                    raise MissChangeBlock(f'Changes before declared ChangeBlock in line {index + 2}')
                 obj.versions.get_by_name(version_name=version_name) \
                     .change_blocks[change_tag].changes.append(item.strip()[1:].strip())
             else:
